@@ -1,6 +1,9 @@
+import google.protobuf.message
+
+ProtobufMessage = google.protobuf.message.Message
+
 from nibiru.client import GrpcClient  # noqa
 from nibiru.common import Coin, Direction, PoolAsset, Side, TxConfig  # noqa
-from nibiru.composer import Composer  # noqa
 from nibiru.network import Network  # noqa
 from nibiru.sdk import Sdk  # noqa
 from nibiru.transaction import Transaction  # noqa
